@@ -36,6 +36,7 @@ class ClientV0:
     def _call(self, api_path, params=None, decoder=cast_dict_or_list):
         if not self.api_key:
             raise Exception("API key not set")
+
         req = requests.get(
             self._url(api_path), headers={"x-api-key": self.api_key}, params=params
         )
@@ -60,9 +61,13 @@ class ClientV0:
         )
 
     def get_asset_dataset(self, dataset, start, end, tickers=None, columns=None):
-        params = {"dataset": dataset, "tickers": tickers, "start": start, "end": end}
-        if columns:
-            params["columns"] = cast_js(columns)
+        params = {
+            "dataset": dataset,
+            "tickers": tickers,
+            "start": start,
+            "end": end,
+            "columns": columns,
+        }
         params["format"] = "msgpack"  # for speed and easier type conversion
         return self._call("/asset_dataset", params=params, decoder=self.coder.decode)
 
