@@ -1,6 +1,6 @@
 import pandas as pd
 
-from utils_ak.split_file import SplitFile
+from qset.utils.split_file import SplitFile
 
 
 class PandasCSVWriter:
